@@ -1,7 +1,7 @@
 """tiny-listener
 """
 
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 from .context import Context, Scope
 from .errors import (
@@ -18,10 +18,11 @@ from .event import Event
 from .hook import Depends, Hook, HookFunc, depend
 from .listener import Listener, get_current_running_listener
 from .routing import Params, Route, compile_path
-from .utils import import_from_string
+from .utils import check_coro_func, import_from_string, is_main_thread
 
 __all__ = [
     "__version__",
+    "check_coro_func",
     "depend",
     "ContextAlreadyExists",
     "ContextNotFound",
@@ -33,6 +34,7 @@ __all__ = [
     "Event",
     "EventAlreadyDone",
     "Depends",
+    "is_main_thread",
     "Hook",
     "HookFunc",
     "ContextNotFound",
